EncryptedStorage class
Encrypted storage
- Implemented types
- Annotations
-
- @singleton
Constructors
- EncryptedStorage()
- Encrypted storage
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
Clear storage: all records
override
-
clearDomain(
[String? domain = defaultDomain]) → Future< void> -
Clear storage: all records in one domain
override
-
delete(
String key, {String domain = defaultDomain}) → Future< void> -
Delete by
keyfromdomain.override -
deleteDomain(
List< String> keys, {String domain = defaultDomain}) → Future<void> -
Delete by
keysfromdomain.override -
get(
String key, {String? defaultValue, String domain = defaultDomain}) → Future< String?> -
Get value by
keyanddomain. If not found will returndefaultValueoverride -
getDomain(
{String domain = defaultDomain}) → Future< Map< String, String> > -
Get key-value pair map from
domain.override -
getDomainKeys(
{String domain = defaultDomain}) → Future< List< String> > -
Get keys from
domainoverride -
init(
{String dbName = _storageFileName, String? databasesPath, FlutterSecureStorage? secureStorage}) → Future< void> - Init encrypted storage
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
{String dbName = _storageFileName, String? databasesPath}) → Future< void> - Reset storage @visibleForTesting
-
set(
String key, String value, {String domain = defaultDomain, bool overwrite = true}) → Future< void> -
Write the key-value pair.
valuewill be written for thekeyindomain. If the pair was already existed it will be overwritten ifoverwriteis true (by default)override -
setDomain(
Map< String, String> pairs, {String domain = defaultDomain, bool overwrite = true}) → Future<void> -
Write the key-value pair map.
pairswill be written indomain. If the pair was already existed it will be overwritten ifoverwriteis true (by default). Unspecified inpairsin db will not be altered or deleted.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited